yt\_idv package
===============

The API of ``yt_idv`` is divided up into the scenegraph, which is the primary
place that folks interact programmatically with the display, and its
subcomponents, which comprise annotations, components, and data.

.. toctree::
   :maxdepth: 4

   yt_idv.scene_graph
   yt_idv.cameras
   yt_idv.rendering_contexts
   yt_idv.scene_annotations
   yt_idv.scene_components
   yt_idv.scene_data
   yt_idv.misc
